function C2CAna(n_start, n_end, FileGroup)
%
%   C2CAna.m is part of the LCM project, published under the terms of GNU
% General Public License.
% 
% ******************************************
% 
%   Author: Jing Su <Jing.Su.66#gmail.com>
%   Copyright 2002-2009 Jing Su
%   Meredith Group, Georgia Tech
% 
% ******************************************
%
% C2CAna(n_start, n_end, FileGroup) analyzes output data from
% ImageProcessing.m (``TotDataOut1.mat'' ... ``TotDataOutlast.mat'') and
% summarize info from all images in the group in folder ``Ana/GroupName''
% (here ``Ana/Example'') as ``tot_C.mat'', ``tot_PP_a.mat'',
% ``tot_PP_d.mat'', ``tot_P_a.mat'', and ``tot_P_d.mat''.
% 
% For example:
%
% C2CAna(0, 395, 'Example')
% 
  
  t_start = cputime;

  if exist([FileGroup,'_BadImages.mat'], 'file'),
    load([FileGroup,'_BadImages']);
  else
    BadImages=[];
  end;

  if exist([FileGroup,'_BadImagesBR.mat'], 'file'),
    load([FileGroup,'_BadImagesBR.mat']);
  else
    BadImagesBR=[];
  end;
  
  % Originally 1e4 bins are used for histogram to preserve details. Later
  % on these 1e4 bins are further grouped for data analysis.
  %
  % The length unit used here is pixel. 
  hist_N = 1e4; 
  dis_Scale = linspace(0,2000,hist_N);
  tot_C = zeros(1,hist_N);
  tot_P_a = zeros(1,hist_N);
  tot_PP_a = zeros(1,hist_N);
  tot_P_d = zeros(1,hist_N);
  tot_PP_d = zeros(1,hist_N);

  tic

    for i = n_start:n_end,
      if (any(BadImages==i)), continue, end;

      InputDataFileName = ...
          fullfile('Ana', FileGroup,['TotDataOut' int2str(i)]);
      DataIn = load(InputDataFileName);    
      DataTemp = DataIn.DataOut;
      
      StatsC = DataTemp.Stats_Cell;
      N_Cell = DataTemp.N_Of_Cell;
      C_Cent = [StatsC.Centroid];        
      C_Cent = reshape(C_Cent,[2,N_Cell]);
      C_Cent = C_Cent';
      
      % This dis_C cal out Cell2Cell distance
      clear Ctmp Cdis dis dis_C;
      Ctmp(1,:,:) = C_Cent';
      % The next two lines are for brain gymnastics
      Cdis = (repmat(C_Cent,[1,1,N_Cell]) - repmat(Ctmp,[N_Cell,1,1])).^2;
      dis(:,:) = triu(reshape(sqrt(Cdis(:,1,:)+Cdis(:,2,:)),N_Cell,N_Cell));
      
      dis_C = dis(dis>0);
      n_C = hist(dis_C,dis_Scale);
      tot_C = tot_C + n_C;
      
      %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
      % Cases using Sum BrdU Intensity
      N_PCell = DataTemp.N_Of_ProlCell_a;
      P_Cent = [DataTemp.Stats_ProlCell_a.Centroid];
      P_Cent = reshape(P_Cent, [2,N_PCell]);
      P_Cent = P_Cent';

      % This dis_P cal out Prol2Cell distance
      % Can be further modified as dis_C and dis_PP, but I am too lazy
      % and it will only save 0.7sec(although more than 50%) per image
      % Modify here later when necessary
      dis_P = zeros(0,1);
      for iP = 1:N_PCell,
        dis = sqrt(sum((repmat(P_Cent(iP,:),N_Cell,1)-C_Cent(:,:)).^2,2));
        dis_P = [dis_P;dis(dis>0)];
      end;

      % This dis_PP cal out Prol2Prol distance
      clear Ptmp Pdis dis dis_PP;
      Ptmp(1,:,:) = P_Cent';
      Pdis = (repmat(P_Cent,[1,1,N_PCell]) - repmat(Ptmp,[N_PCell,1,1])).^2;
      dis(:,:) = triu(reshape(sqrt(Pdis(:,1,:)+Pdis(:,2,:)),N_PCell,N_PCell));
      dis_PP = dis(dis>0);


      n_P = hist(dis_P,dis_Scale);

      if sum((2*n_C)<n_P),
        ['ERROR: the ', int2str(i), 'th Image: 2*n_C < n_P']
        break,
      end;

      n_PP = hist(dis_PP, dis_Scale);

      tot_P_a = tot_P_a + n_P;
      tot_PP_a = tot_PP_a + n_PP;
      %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
      % Cases using Average BrdU Intensity
      N_PCell = DataTemp.N_Of_ProlCell_d;
      P_Cent = [DataTemp.Stats_ProlCell_d.Centroid];
      P_Cent = reshape(P_Cent, [2,N_PCell]);
      P_Cent = P_Cent';

      % This dis_P cal out Prol2Cell distance
      % Can be further modified as dis_C and dis_PP, but I am too lazy
      % and it will only save 0.7sec(although more than 50%) per image
      % Modify here later when necessary
      dis_P = zeros(0,1);
      for iP = 1:N_PCell,
        dis = sqrt(sum((repmat(P_Cent(iP,:),N_Cell,1)-C_Cent(:,:)).^2,2));
        dis_P = [dis_P;dis(dis>0)];
      end;

      % This dis_PP cal out Prol2Prol distance
      clear Ptmp Pdis dis dis_PP;
      Ptmp(1,:,:) = P_Cent';
      Pdis = (repmat(P_Cent,[1,1,N_PCell]) - repmat(Ptmp,[N_PCell,1,1])).^2;
      dis(:,:) = triu(reshape(sqrt(Pdis(:,1,:)+Pdis(:,2,:)),N_PCell,N_PCell));
      dis_PP = dis(dis>0);


      n_P = hist(dis_P,dis_Scale);

      if sum((2*n_C)<n_P),
        ['ERROR: the ', int2str(i), 'th Image: 2*n_C < n_P']
        break,
      end;

      n_PP = hist(dis_PP, dis_Scale);

      tot_P_d = tot_P_d + n_P;
      tot_PP_d = tot_PP_d + n_PP;
      
      [int2str(i-n_start+1) ' of ' int2str(n_end-n_start+1) ' , time used: ' ...
       int2str(round(toc)) 'Sec.']
    end;
    
    save(fullfile('Ana', FileGroup, 'tot_C'), 'tot_C', '-v6');
    save(fullfile('Ana', FileGroup, 'tot_P_a'), 'tot_P_a', '-v6');
    save(fullfile('Ana', FileGroup, 'tot_PP_a'), 'tot_PP_a', '-v6');
    save(fullfile('Ana', FileGroup, 'tot_P_d'), 'tot_P_d', '-v6');
    save(fullfile('Ana', FileGroup, 'tot_PP_d'), 'tot_PP_d', '-v6');
    save(fullfile('Ana', FileGroup, 'dis_Scale'), 'dis_Scale', '-v6');


    t_end = cputime;
    t_used = t_end - t_start




