function C2CNorm(FileGroups)
%
% C2CNorm.m is part of the LCM project, published under the terms of GNU
%   General Public License.
% 
% ******************************************
% 
%   Author: Jing Su <Jing.Su.66#gmail.com>
%   Copyright 2002-2009 Jing Su
%   Meredith Group, Georgia Tech
% 
% ******************************************
%
%  Defined in the string cell array ``FileGroups'', multiple file groups are
%  precessed. LCMs are generated, stored in Data, and plotted.
% 
% For example:
%
% C2CNorm({'Example'})
% 
  

  Data = struct;
  load('hist_coll');
  for FileGroup = FileGroups,
    Group = cell2mat(FileGroup(1));
    load(fullfile('Ana', Group, 'tot_C'));
    load(fullfile('Ana', Group, 'tot_P_d'));
    load(fullfile('Ana', Group, 'tot_PP_d'));
    load(fullfile('Ana', Group, 'dis_Scale'));

    Data.(Group).tot_AA = 2*tot_C;
    Data.(Group).tot_PP = 2*tot_PP_d;
    Data.(Group).tot_P = tot_P_d;
    Data.(Group).tot_PA = Data.(Group).tot_P;
    Data.(Group).tot_std = hist_coll;
    % From here on the distance unit is miron
    Data.(Group).r_dis = dis_Scale*1280/1600;

    Data.(Group).tot_AA(1) = 0;
    Data.(Group).tot_PA(1) = 0;
    Data.(Group).tot_PP(1) = 0;

    Data.(Group).tot_PR = Data.(Group).tot_PA - Data.(Group).tot_PP;
    Data.(Group).tot_RP = Data.(Group).tot_PR;
    Data.(Group).tot_AP = Data.(Group).tot_PA;
    Data.(Group).tot_RA = Data.(Group).tot_AA - Data.(Group).tot_PA;
    Data.(Group).tot_RR = Data.(Group).tot_RA - Data.(Group).tot_RP;
    Data.(Group).tot_RR = Data.(Group).tot_AA - Data.(Group).tot_PP - 2*Data.(Group).tot_PR;

    Data.(Group).f_AA = Data.(Group).tot_AA/sum(Data.(Group).tot_AA);
    Data.(Group).f_PA = Data.(Group).tot_PA/sum(Data.(Group).tot_PA);
    Data.(Group).f_PP = Data.(Group).tot_PP/sum(Data.(Group).tot_PP);
    Data.(Group).f_PR = Data.(Group).tot_PR/sum(Data.(Group).tot_PR);
    Data.(Group).f_RR = Data.(Group).tot_RR/sum(Data.(Group).tot_RR);
    Data.(Group).f_std = Data.(Group).tot_std/sum(Data.(Group).tot_std);

    Data.(Group).hist_N = length(Data.(Group).r_dis);
    Data.(Group).x_bind = 50;                          % binding bins
    Data.(Group).x_N = round(Data.(Group).hist_N/Data.(Group).x_bind);
    [Data.(Group).x_idx, Data.(Group).x_dis] = hist(Data.(Group).r_dis,Data.(Group).x_N);
    Data.(Group).x_idx = [0, cumsum(Data.(Group).x_idx)];

    Data.(Group).xf_AA = zeros(1,Data.(Group).hist_N/Data.(Group).x_bind-1);
    Data.(Group).xf_PA = zeros(1,Data.(Group).hist_N/Data.(Group).x_bind-1);
    Data.(Group).xf_PP = zeros(1,Data.(Group).hist_N/Data.(Group).x_bind-1);
    Data.(Group).xf_PR = zeros(1,Data.(Group).hist_N/Data.(Group).x_bind-1);
    Data.(Group).xf_RR = zeros(1,Data.(Group).hist_N/Data.(Group).x_bind-1);
    Data.(Group).xf_std = zeros(1,Data.(Group).hist_N/Data.(Group).x_bind-1);

    for i=1:Data.(Group).x_N,
      Data.(Group).xf_AA(i) = sum(Data.(Group).f_AA((Data.(Group).x_idx(i)+1):Data.(Group).x_idx(i+1)));
      Data.(Group).xf_PA(i) = sum(Data.(Group).f_PA((Data.(Group).x_idx(i)+1):Data.(Group).x_idx(i+1)));
      Data.(Group).xf_PP(i) = sum(Data.(Group).f_PP((Data.(Group).x_idx(i)+1):Data.(Group).x_idx(i+1)));
      Data.(Group).xf_PR(i) = sum(Data.(Group).f_PR((Data.(Group).x_idx(i)+1):Data.(Group).x_idx(i+1)));
      Data.(Group).xf_RR(i) = sum(Data.(Group).f_RR((Data.(Group).x_idx(i)+1):Data.(Group).x_idx(i+1)));
      Data.(Group).xf_std(i) = sum(Data.(Group).f_std((Data.(Group).x_idx(i)+1):Data.(Group).x_idx(i+1)));
    end;

    % Normalizing xf's with xf_std to get nf's
    Data.(Group).nf_AA = Data.(Group).xf_AA./Data.(Group).xf_std;
    Data.(Group).nf_PA = Data.(Group).xf_PA./Data.(Group).xf_std;
    Data.(Group).nf_PP = Data.(Group).xf_PP./Data.(Group).xf_std;
    Data.(Group).nf_PR = Data.(Group).xf_PR./Data.(Group).xf_std;
    Data.(Group).nf_RR = Data.(Group).xf_RR./Data.(Group).xf_std;
    
    %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
    % Detailed: 0~80um
    Data.(Group).d_r_dis = Data.(Group).r_dis;
    Data.(Group).d_hist_N = length(Data.(Group).d_r_dis);
    Data.(Group).d_x_bind = 16;                          % binding bins 
    Data.(Group).d_x_N = round(Data.(Group).d_hist_N/Data.(Group).d_x_bind);
    [Data.(Group).d_x_idx, Data.(Group).d_x_dis] = hist(Data.(Group).d_r_dis,Data.(Group).d_x_N);
    Data.(Group).d_x_idx = [0, cumsum(Data.(Group).d_x_idx)];
    
    Data.(Group).d_xf_AA = zeros(1,Data.(Group).d_hist_N/Data.(Group).d_x_bind-1);
    Data.(Group).d_xf_PA = zeros(1,Data.(Group).d_hist_N/Data.(Group).d_x_bind-1);
    Data.(Group).d_xf_PP = zeros(1,Data.(Group).d_hist_N/Data.(Group).d_x_bind-1);
    Data.(Group).d_xf_PR = zeros(1,Data.(Group).d_hist_N/Data.(Group).d_x_bind-1);
    Data.(Group).d_xf_RR = zeros(1,Data.(Group).d_hist_N/Data.(Group).d_x_bind-1);
    Data.(Group).d_xf_std = zeros(1,Data.(Group).d_hist_N/Data.(Group).d_x_bind-1);
    
    for i=1:Data.(Group).d_x_N,
      Data.(Group).d_xf_AA(i) = sum(Data.(Group).f_AA((Data.(Group).d_x_idx(i)+1):Data.(Group).d_x_idx(i+1)));
      Data.(Group).d_xf_PA(i) = sum(Data.(Group).f_PA((Data.(Group).d_x_idx(i)+1):Data.(Group).d_x_idx(i+1)));
      Data.(Group).d_xf_PP(i) = sum(Data.(Group).f_PP((Data.(Group).d_x_idx(i)+1):Data.(Group).d_x_idx(i+1)));
      Data.(Group).d_xf_PR(i) = sum(Data.(Group).f_PR((Data.(Group).d_x_idx(i)+1):Data.(Group).d_x_idx(i+1)));
      Data.(Group).d_xf_RR(i) = sum(Data.(Group).f_RR((Data.(Group).d_x_idx(i)+1):Data.(Group).d_x_idx(i+1)));
      Data.(Group).d_xf_std(i) = sum(Data.(Group).f_std((Data.(Group).d_x_idx(i)+1):Data.(Group).d_x_idx(i+1)));
    end;
    
    % Normalizing xf's with Data.(Group).d_xf_std to get nf's
    Data.(Group).d_nf_AA = Data.(Group).d_xf_AA./Data.(Group).d_xf_std;
    Data.(Group).d_nf_PA = Data.(Group).d_xf_PA./Data.(Group).d_xf_std;
    Data.(Group).d_nf_PP = Data.(Group).d_xf_PP./Data.(Group).d_xf_std;
    Data.(Group).d_nf_PR = Data.(Group).d_xf_PR./Data.(Group).d_xf_std;
    Data.(Group).d_nf_RR = Data.(Group).d_xf_RR./Data.(Group).d_xf_std;
    
    % Comparison
    Data.(Group).d_nf_PAvsAA = Data.(Group).d_nf_PA ./ Data.(Group).d_nf_AA;
    Data.(Group).d_nf_PAvsAA(isinf(Data.(Group).d_nf_PAvsAA)) = NaN;
    Data.(Group).d_nf_PRvsRR = Data.(Group).d_nf_PR ./ Data.(Group).d_nf_RR;
    Data.(Group).d_nf_PRvsRR(isinf(Data.(Group).d_nf_PRvsRR)) = NaN;
    
    
    Data.(Group).d_dis_detail = 80;               % 80microns
    Data.(Group).d_dx_N = sum(Data.(Group).d_x_dis<=Data.(Group).d_dis_detail);
    
  end;
  clear Group FileGroup tot_C tot_P_d tot_PP_d dis_Scale hist_coll;

  save(fullfile('Ana', 'DataNormC2C'), 'Data', '-v6');


  %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
  %                                                 %
  %                    PLOTING                      %
  %                                                 %
  %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
  for FileGroup = FileGroups,
    Group = cell2mat(FileGroup(1));
    for caC2CDist = {'AA','PP','RR','PR','PA', 'PAvsAA', 'PRvsRR'}
      C2CDist = cell2mat(caC2CDist);
      Plot_d_NormC2CDist(Group, Data, C2CDist);
    end;
  end;

