function ProofReading(n_start, n_end, FileGroup)
%  
% ProofReading.m is part of the LCM project, published under the terms of
% GNU General Public License.
% 
% ******************************************
% 
%   Author: Jing Su <Jing.Su.66#gmail.com>
%   Copyright 2002-2009 Jing Su
%   Meredith Group, Georgia Tech
% 
% ******************************************
%
% ProofReading(n_start, n_end, FileGroup) visualizes image processing
% results as images in folder ``PreProcess/Proof'' for proofreading.
% 
% For example:
%
% ProofReading(0, 395, 'Example')
% 
  
  t_start = cputime;

  tic;
    
    if exist([FileGroup,'_BadImages.mat']),
      load([FileGroup,'_BadImages']);
    else
      BadImages=[];
    end;

    for i = n_start:n_end,
      if (any(BadImages==i)), continue, end;
      
      %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
      %
      %  Check the counter staining
      %
      %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
      clear i_outB t_tmp i_outR;
      FileName = [FileGroup, '_B_10X_',int2str(i)];
      FullFileName = fullfile(FileGroup,FileName);
      i_tmp = imread(FullFileName, 'JPEG');
      i_outB = i_tmp;

      FileNameWS = [FileName '-WS' '.jpg'];
      FullFileName = fullfile( ...
          'PreProcess', FileGroup, 'B', ...
          FileNameWS);
      i_tmp = imread(FullFileName, 'JPEG');
      edge_B = imdilate(i_tmp,strel('disk',2)) - imerode(i_tmp,strel('disk',1));
      i_outB(:,:,1) = i_outB(:,:,1) + edge_B;
      i_outB(:,:,2) = i_outB(:,:,2).*uint8(edge_B<127);
      i_outB(:,:,3) = i_outB(:,:,3).*uint8(edge_B<127);

      FullFileName = fullfile( ...
          'PreProcess', FileGroup, 'Proof', ...
          ['ProofB',int2str(i),'.jpg']);
      imwrite(i_outB, FullFileName, 'JPEG');

      %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
      %
      %  Check the BrdU staining
      %
      %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

      i_outR = repmat(OpenImage([FileGroup, '_G_10X_'], i, '.jpg', FileGroup, ...
                                'gray'), [1,1,3]);

      Dir = fullfile('PreProcess', FileGroup, 'R');
      FullFileName = fullfile( ...
          'PreProcess', FileGroup, 'R', ...
          [FileGroup,'_R_10X_',int2str(i),'-BrdU-d-Cutoff.jpg']);
      i_r_d = imread(FullFileName, 'JPEG');

      FullFileName = fullfile( ...
          'PreProcess', FileGroup, 'R', ...
          [FileGroup,'_R_10X_',int2str(i),'-BrdU-s-Cutoff.jpg']);
      i_r_s = imread(FullFileName, 'JPEG');

      edge_d = imdilate(i_r_d(:,:,1),strel('disk',2)) - imerode(i_r_d(:,:,1), ...
                                                        strel('disk',1));
      edge_s = imdilate(i_r_s(:,:,1),strel('disk',2)) - imerode(i_r_s(:,:,1), ...
                                                        strel('disk',1));
      i_outR(:,:,1) = i_outR(:,:,1) + edge_d(:,:,1);
      i_outR(:,:,2) = i_outR(:,:,2) + edge_s(:,:,1);
      i_outR(:,:,3) = i_outR(:,:,3).*uint8((edge_d(:,:,1)+edge_s(:,:,1))<127)+ edge_B;

      FullFileName = fullfile( ...
          'PreProcess', FileGroup, 'Proof', ...
          ['ProofR',int2str(i),'.jpg']);
      imwrite(i_outR, FullFileName, 'JPEG');

      [int2str(i-n_start+1) ' of ' int2str(n_end-n_start+1) ' , time used: ' ...
       int2str(round(toc)) 'Sec.']

    end;

